@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the test suite of the Qt Toolkit.
 **
@@ -10,9 +10,9 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -23,8 +23,8 @@
 ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
+** As a special exception, The Qt Company gives you certain additional
+** rights. These rights are described in The Qt Company LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** $QT_END_LICENSE$
@@ -36,6 +36,9 @@
 #include <QtTest/QtTest>
 #include <QtGui/QGuiApplication>
 #include <QtGui/qpa/qwindowsysteminterface.h>
+#include <QtGui/QStyleHints>
+
+QT_BEGIN_NAMESPACE
 
 QDeclarativePinchGenerator::QDeclarativePinchGenerator():
     target_(0),
@@ -331,7 +334,7 @@ void QDeclarativePinchGenerator::pinchRelease(QPoint point1To, QPoint point2To)
     QTest::touchEvent(window_, device_).release(0, point1To).release(1, point2To);
 }
 
-Q_INVOKABLE void QDeclarativePinchGenerator::replay()
+void QDeclarativePinchGenerator::replay()
 {
     if (state_ != Idle) {
         qDebug() << "Wrong state, will not replay pinch, state: " << state_;
@@ -354,7 +357,7 @@ Q_INVOKABLE void QDeclarativePinchGenerator::replay()
     setState(Replaying);
 }
 
-Q_INVOKABLE void QDeclarativePinchGenerator::clear()
+void QDeclarativePinchGenerator::clear()
 {
     stop();
     delete activeSwipe_;
@@ -365,7 +368,7 @@ Q_INVOKABLE void QDeclarativePinchGenerator::clear()
     }
 }
 
-Q_INVOKABLE void QDeclarativePinchGenerator::stop()
+void QDeclarativePinchGenerator::stop()
 {
     if (state_ != Replaying)
         return;
@@ -375,3 +378,10 @@ Q_INVOKABLE void QDeclarativePinchGenerator::stop()
     replayTimer_ = -1;
     setState(Idle);
 }
+
+int QDeclarativePinchGenerator::startDragDistance()
+{
+    return qApp->styleHints()->startDragDistance();
+}
+
+QT_END_NAMESPACE
